@@ -18,6 +18,8 @@
 #' @param spmdir SPM dir to add, will use package default directory
 #' @param clean Remove scripts from temporary directory after running
 #' @param verbose Print diagnostic messages
+#' @param install_dir directory to download SPM12
+#' 
 #' @param ... Arguments passed to \code{\link{run_spm12_script}}
 #' @export
 #' @return List of SPM object, results, and output filenames
@@ -26,7 +28,8 @@
 #' temp_nii = array(rnorm(prod(dims)), dim = dims)
 #' temp_nii = oro.nifti::nifti(temp_nii)
 #' res = build_spm12_normalize_write(temp_nii, 
-#' other.files = temp_nii)
+#' other.files = temp_nii,
+#' install_dir = tempdir())
 spm12_normalize_write <- function(
   deformation,
   other.files = NULL,
@@ -41,13 +44,16 @@ spm12_normalize_write <- function(
   retimg = FALSE,
   reorient = FALSE,
   add_spm_dir = TRUE,
-  spmdir = spm_dir(verbose = verbose),
+  spmdir = spm_dir(verbose = verbose,
+                   install_dir = install_dir),
   clean = TRUE,
   verbose = TRUE,
+  install_dir = NULL,
   ...
 ){
   
-  install_spm12(verbose = verbose)
+  install_spm12(verbose = verbose,
+                install_dir = install_dir)
   
   L = build_spm12_normalize_write(
     deformation = deformation,
