@@ -4,10 +4,10 @@
 % cfg_basicio BasicIO - Unknown
 %-----------------------------------------------------------------------
 matlabbatch{1}.spm.spatial.normalise.est.subj.vol = {'%filename%'};
-matlabbatch{1}.spm.spatial.normalise.est.eoptions.biasreg = 0.0001;
-matlabbatch{1}.spm.spatial.normalise.est.eoptions.biasfwhm = 60;
+matlabbatch{1}.spm.spatial.normalise.est.eoptions.biasreg = %biasreg%;
+matlabbatch{1}.spm.spatial.normalise.est.eoptions.biasfwhm = %biasfwhm%;
 matlabbatch{1}.spm.spatial.normalise.est.eoptions.tpm = {'%spmdir%/tpm/TPM.nii'};
-matlabbatch{1}.spm.spatial.normalise.est.eoptions.affreg = 'mni';
-matlabbatch{1}.spm.spatial.normalise.est.eoptions.reg = [0 0.001 0.5 0.05 0.2];
-matlabbatch{1}.spm.spatial.normalise.est.eoptions.fwhm = 0;
-matlabbatch{1}.spm.spatial.normalise.est.eoptions.samp = 3;
+matlabbatch{1}.spm.spatial.normalise.est.eoptions.affreg = %affreg%';
+matlabbatch{1}.spm.spatial.normalise.est.eoptions.reg = %reg%;
+matlabbatch{1}.spm.spatial.normalise.est.eoptions.fwhm = %fwhm%;
+matlabbatch{1}.spm.spatial.normalise.est.eoptions.samp = %samp%;
